Returns the fitted time parameter, trait covariance components, and public series–occasion index for a native temporal-source fit.
Returns the fitted time parameter, trait covariance components, and public series–occasion index for a native temporal-source fit.