Skip to contents

Draw mesh edges and the observed locations. This is the plot method for meshes created by make_mesh().

Usage

# S3 method for class 'gllvmTMBmesh'
plot(x, ...)

# S3 method for class 'sdmTMBmesh'
plot(x, ...)

Arguments

x

A gllvmTMBmesh created by make_mesh().

...

Passed to graphics::plot().

Value

Invisibly returns x after drawing mesh edges, observations, and optional k-means centres.

Details

plot.sdmTMBmesh() is a temporary legacy compatibility method. New meshes have class gllvmTMBmesh and should be plotted with plot.gllvmTMBmesh().