Returns the linear predictor (and conditional response) at each
observation in the training data, or the fixed-effects-only prediction
at user-supplied newdata (for sites / species not present in the
training data we cannot draw the corresponding random effects, so
predictions are returned on the population mean).
Arguments
- object
A
gllvmTMB_multifit.- newdata
Optional new data frame. If
NULL, predictions are produced for the training rows.- type
One of
"link"(default) or"response".- re_form
Random-effect formula controlling which random effects are included in the predicted linear predictor. Use the default
~ .to include all random effects when predicting on training rows; pass~ 0(orNA) to predict the fixed- effects-only / population-mean prediction. Fornewdatawith sites/species not present in the training data the random effects cannot be drawn, so the prediction is fixed-effects-only regardless ofre_form.- ...
Unused.